@@ -1,22 +1,22 @@
 # *************************************************************************
-# Copyright (c) 2014-2016, SUSE LLC
-# 
+# Copyright (c) 2014-2017, SUSE LLC
+#
 # All rights reserved.
-# 
+#
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
-# 
+#
 # 1. Redistributions of source code must retain the above copyright notice,
 # this list of conditions and the following disclaimer.
-# 
+#
 # 2. Redistributions in binary form must reproduce the above copyright
 # notice, this list of conditions and the following disclaimer in the
 # documentation and/or other materials provided with the distribution.
-# 
+#
 # 3. Neither the name of SUSE LLC nor the names of its contributors may be
 # used to endorse or promote products derived from this software without
 # specific prior written permission.
-# 
+#
 # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 # AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 # IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -406,7 +406,7 @@ Sync the mapping fields to the values found in the LDAP database.
 sub ldap_sync {
     my $self = shift;
     $log->debug( "Entering " . __PACKAGE__ . "::sync()" );
-    die "Employee nick property not populated!" unless $self->nick;
+    die "Employee nick property not populated!" unless $self->nick =~ /\S+/;
     my $nick = $self->nick;
 
     return $CELL->status_err( 'DOCHAZKA_LDAP_NOT_ENABLED' ) unless $site->DOCHAZKA_LDAP;
@@ -675,7 +675,7 @@ sub team_nicks {
     return $CELL->status_ok( 'TEAM', payload => [] ) unless $self->eid;
 
     # if nick not populated, get it
-    $self->load_by_eid( $conn, $self->eid ) unless $self->nick;
+    $self->load_by_eid( $conn, $self->eid ) unless $self->nick =~ /\S+/;
 
     my $status = select_set_of_single_scalar_rows( 
         'conn' => $conn,
